==> jc-1.4.0.tar.gz: java/io/ObjectStreamConstants.h <==
// public abstract interface java.io.ObjectStreamConstants

// class file dependencies
// @dep_class 6b700c298d048456 java_io_ObjectStreamConstants
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamConstants_H_
#define _JC_java_io_ObjectStreamConstants_H_

// Typedefs
typedef struct _jc_java_io_ObjectStreamConstants$fields_struct	_jc_java_io_ObjectStreamConstants$fields_struct;
typedef const struct _jc_java_io_ObjectStreamConstants$vtype	_jc_java_io_ObjectStreamConstants$vtype;

// Class fields structure
struct _jc_java_io_ObjectStreamConstants$fields_struct {
	struct _jc_java_io_SerializablePermission$object	*SUBCLASS__5fIMPLEMENTATION__5fPERMISSION;
	struct _jc_java_io_SerializablePermission$object	*SUBSTITUTION__5fPERMISSION;
	jint	PROTOCOL__5fVERSION__5f1;
	jint	PROTOCOL__5fVERSION__5f2;
	jint	baseWireHandle;
	jshort	STREAM__5fMAGIC;
	jshort	STREAM__5fVERSION;
	jbyte	SC__5fBLOCK__5fDATA;
	jbyte	SC__5fEXTERNALIZABLE;
	jbyte	SC__5fSERIALIZABLE;
	jbyte	SC__5fWRITE__5fMETHOD;
	jbyte	TC__5fARRAY;
	jbyte	TC__5fBASE;
	jbyte	TC__5fBLOCKDATA;
	jbyte	TC__5fBLOCKDATALONG;
	jbyte	TC__5fCLASS;
	jbyte	TC__5fCLASSDESC;
	jbyte	TC__5fENDBLOCKDATA;
	jbyte	TC__5fEXCEPTION;
	jbyte	TC__5fLONGSTRING;
	jbyte	TC__5fMAX;
	jbyte	TC__5fNULL;
	jbyte	TC__5fOBJECT;
	jbyte	TC__5fPROXYCLASSDESC;
	jbyte	TC__5fREFERENCE;
	jbyte	TC__5fRESET;
	jbyte	TC__5fSTRING;
};
extern _jc_java_io_ObjectStreamConstants$fields_struct _jc_java_io_ObjectStreamConstants$class_fields;

// Static methods
extern void _jc_java_io_ObjectStreamConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_java_io_ObjectStreamConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_io_ObjectStreamConstants$vtype _jc_java_io_ObjectStreamConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamConstants$class_object;

#endif	/* _JC_java_io_ObjectStreamConstants_H_ */

==> jc-1.4.6.tar.gz: java/io/ObjectStreamConstants.h <==
// public abstract interface java.io.ObjectStreamConstants

// class file dependencies
// @dep_class 6b700c298d048456 java_io_ObjectStreamConstants
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamConstants_H_
#define _JC_java_io_ObjectStreamConstants_H_

// Typedefs
typedef struct _jc_java_io_ObjectStreamConstants$fields_struct	_jc_java_io_ObjectStreamConstants$fields_struct;
typedef const struct _jc_java_io_ObjectStreamConstants$vtype	_jc_java_io_ObjectStreamConstants$vtype;

// Class fields structure
struct _jc_java_io_ObjectStreamConstants$fields_struct {
	struct _jc_java_io_SerializablePermission$object	*SUBCLASS__5fIMPLEMENTATION__5fPERMISSION;
	struct _jc_java_io_SerializablePermission$object	*SUBSTITUTION__5fPERMISSION;
	jint	PROTOCOL__5fVERSION__5f1;
	jint	PROTOCOL__5fVERSION__5f2;
	jint	baseWireHandle;
	jshort	STREAM__5fMAGIC;
	jshort	STREAM__5fVERSION;
	jbyte	SC__5fBLOCK__5fDATA;
	jbyte	SC__5fEXTERNALIZABLE;
	jbyte	SC__5fSERIALIZABLE;
	jbyte	SC__5fWRITE__5fMETHOD;
	jbyte	TC__5fARRAY;
	jbyte	TC__5fBASE;
	jbyte	TC__5fBLOCKDATA;
	jbyte	TC__5fBLOCKDATALONG;
	jbyte	TC__5fCLASS;
	jbyte	TC__5fCLASSDESC;
	jbyte	TC__5fENDBLOCKDATA;
	jbyte	TC__5fEXCEPTION;
	jbyte	TC__5fLONGSTRING;
	jbyte	TC__5fMAX;
	jbyte	TC__5fNULL;
	jbyte	TC__5fOBJECT;
	jbyte	TC__5fPROXYCLASSDESC;
	jbyte	TC__5fREFERENCE;
	jbyte	TC__5fRESET;
	jbyte	TC__5fSTRING;
};
extern _jc_java_io_ObjectStreamConstants$fields_struct _jc_java_io_ObjectStreamConstants$class_fields;

// Static methods
extern void _jc_java_io_ObjectStreamConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_java_io_ObjectStreamConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_io_ObjectStreamConstants$vtype _jc_java_io_ObjectStreamConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamConstants$class_object;

#endif	/* _JC_java_io_ObjectStreamConstants_H_ */
